//
// HtWordReference.h
//
// HtWordReference: Reference to a word, derived from WordReference and
//		    implementing explicit accessors.
//
// Part of the ht://Dig package   <http://www.htdig.org/>
// Copyright (c) 1995-2002 The ht://Dig Group
// For copyright details, see the file COPYING in your distribution
// or the GNU Public License version 2 or later
// <http://www.gnu.org/copyleft/gpl.html>
//
// $Id: HtWordReference.h,v 1.3 2002/02/01 22:49:28 ghutchis Exp $
//
#ifndef _HtWordReference_h_
#define _HtWordReference_h_

#include "Object.h"
#include "WordReference.h"
#include <stdio.h>

//
// Flags
// 
#define FLAG_TEXT 0
#define FLAG_CAPITAL 1
#define FLAG_TITLE 2
#define FLAG_HEADING 4
#define FLAG_KEYWORDS 8
#define FLAG_DESCRIPTION 16
#define FLAG_AUTHOR 32
#define FLAG_LINK_TEXT 64
#define FLAG_URL 128
// The remainder (16 more bits) are undefined

class HtWordReference: public Object
{
 private:
  String        _Word;
  unsigned int	_DocID;
  unsigned int	_Flags;
  unsigned int	_Location;
  unsigned int	_Anchor;

 public:
	//
	// Construction/Destruction
	//
        HtWordReference()	{}
        HtWordReference(const String& key, const String& record);
        HtWordReference(const String& word);
        HtWordReference(String word, unsigned int docid, 
			unsigned int flags, unsigned int location, 
			unsigned int anchor);

	~HtWordReference()	{}

	//
	// Accessors
	//
	String			Word() const {return _Word;}
	void			Word(const String &arg) {_Word = arg;}
	unsigned int		DocID() const {return _DocID;}
	void			DocID(const unsigned int arg) {_DocID = arg;}
	unsigned int		Flags() const {return _Flags;}
	void			Flags(const unsigned int arg) {_Flags = arg;}
	unsigned int		Location() const {return _Location;}
	void			Location(const unsigned int arg) {_Location = arg;}
	unsigned int		Anchor() const {return _Anchor;}
	void			Anchor(const unsigned int arg) {_Anchor = arg;}

	//
	// Meta-Accessors (i.e. return assembled data)
	//
	String			Key() const;
	int			Key(const String &arg);
	void			Key(const String &word, unsigned int DocID,
				    unsigned int flags, unsigned int location);
	String			Record() const;
	void			Record(const unsigned int arg) {Anchor(arg);}

	//
	// Dumping/Loading
	//
	int			Dump(FILE *fl) const;
	static int		DumpHeader(FILE *fl);
	int			Load(const String& s);
	static int		LoadHeader(FILE *fl);
};


#endif


